@@ -107,12 +107,12 @@ removeNumbers <- function(x) UseMethod("removeNumbers", x)
 removeNumbers.PlainTextDocument <- function(x) gsub("[[:digit:]]+", "", x)
 
 removePunctuation <- function(x) UseMethod("removePunctuation", x)
-removePunctuation.PlainTextDocument <- function(x)  gsub("[[:punct:]]+", "", x)
+removePunctuation.PlainTextDocument <- function(x) gsub("[[:punct:]]+", "", x)
 
 removeWords <- function(x, words) UseMethod("removeWords", x)
 # Improvements by Kurt Hornik
 removeWords.PlainTextDocument <- function(x, words)
-    gsub(sprintf("[[:blank:]]+((%s)[[:blank:]])+", paste(words, collapse = "|")), " ", x)
+    gsub(sprintf("\\b(%s)\\b", paste(words, collapse = "|")), "", x)
 
 stemDocument <- function(x, language = "english") UseMethod("stemDocument", x)
 stemDocument.PlainTextDocument <- function(x, language = "english") {
@@ -123,4 +123,4 @@ stemDocument.PlainTextDocument <- function(x, language = "english") {
 }
 
 stripWhitespace <- function(x) UseMethod("stripWhitespace", x)
-stripWhitespace.PlainTextDocument <- function(x)  gsub("[[:space:]]+", " ", x)
+stripWhitespace.PlainTextDocument <- function(x) gsub("[[:space:]]+", " ", x)
